@@ -59,15 +59,15 @@ mod io;
 mod protocol;
 
 pub use error::NoiseError;
-pub use io::NoiseOutput;
 pub use io::handshake;
-pub use io::handshake::{Handshake, RemoteIdentity, IdentityExchange};
-pub use protocol::{Keypair, AuthenticKeypair, KeypairIdentity, PublicKey, SecretKey};
-pub use protocol::{Protocol, ProtocolParams, IX, IK, XX};
+pub use io::handshake::{Handshake, IdentityExchange, RemoteIdentity};
+pub use io::NoiseOutput;
 pub use protocol::{x25519::X25519, x25519_spec::X25519Spec};
+pub use protocol::{AuthenticKeypair, Keypair, KeypairIdentity, PublicKey, SecretKey};
+pub use protocol::{Protocol, ProtocolParams, IK, IX, XX};
 
 use futures::prelude::*;
-use libp2p_core::{identity, PeerId, UpgradeInfo, InboundUpgrade, OutboundUpgrade};
+use libp2p_core::{identity, InboundUpgrade, OutboundUpgrade, PeerId, UpgradeInfo};
 use std::pin::Pin;
 use zeroize::Zeroize;
 
@@ -78,7 +78,7 @@ pub struct NoiseConfig<P, C: Zeroize, R = ()> {
     params: ProtocolParams,
     legacy: LegacyConfig,
     remote: R,
-    _marker: std::marker::PhantomData<P>
+    _marker: std::marker::PhantomData<P>,
 }
 
 impl<H, C: Zeroize, R> NoiseConfig<H, C, R> {
@@ -97,7 +97,7 @@ impl<H, C: Zeroize, R> NoiseConfig<H, C, R> {
 
 impl<C> NoiseConfig<IX, C>
 where
-    C: Protocol<C> + Zeroize
+    C: Protocol<C> + Zeroize,
 {
     /// Create a new `NoiseConfig` for the `IX` handshake pattern.
     pub fn ix(dh_keys: AuthenticKeypair<C>) -> Self {
@@ -106,14 +106,14 @@ where
             params: C::params_ix(),
             legacy: LegacyConfig::default(),
             remote: (),
-            _marker: std::marker::PhantomData
+            _marker: std::marker::PhantomData,
         }
     }
 }
 
 impl<C> NoiseConfig<XX, C>
 where
-    C: Protocol<C> + Zeroize
+    C: Protocol<C> + Zeroize,
 {
     /// Create a new `NoiseConfig` for the `XX` handshake pattern.
     pub fn xx(dh_keys: AuthenticKeypair<C>) -> Self {
@@ -122,14 +122,14 @@ where
             params: C::params_xx(),
             legacy: LegacyConfig::default(),
             remote: (),
-            _marker: std::marker::PhantomData
+            _marker: std::marker::PhantomData,
         }
     }
 }
 
 impl<C> NoiseConfig<IK, C>
 where
-    C: Protocol<C> + Zeroize
+    C: Protocol<C> + Zeroize,
 {
     /// Create a new `NoiseConfig` for the `IK` handshake pattern (recipient side).
     ///
@@ -141,14 +141,14 @@ where
             params: C::params_ik(),
             legacy: LegacyConfig::default(),
             remote: (),
-            _marker: std::marker::PhantomData
+            _marker: std::marker::PhantomData,
         }
     }
 }
 
 impl<C> NoiseConfig<IK, C, (PublicKey<C>, identity::PublicKey)>
 where
-    C: Protocol<C> + Zeroize
+    C: Protocol<C> + Zeroize,
 {
     /// Create a new `NoiseConfig` for the `IK` handshake pattern (initiator side).
     ///
@@ -157,14 +157,14 @@ where
     pub fn ik_dialer(
         dh_keys: AuthenticKeypair<C>,
         remote_id: identity::PublicKey,
-        remote_dh: PublicKey<C>
+        remote_dh: PublicKey<C>,
     ) -> Self {
         NoiseConfig {
             dh_keys,
             params: C::params_ik(),
             legacy: LegacyConfig::default(),
             remote: (remote_dh, remote_id),
-            _marker: std::marker::PhantomData
+            _marker: std::marker::PhantomData,
         }
     }
 }
@@ -182,14 +182,19 @@ where
     type Future = Handshake<T, C>;
 
     fn upgrade_inbound(self, socket: T, _: Self::Info) -> Self::Future {
-        let session = self.params.into_builder()
+        let session = self
+            .params
+            .into_builder()
             .local_private_key(self.dh_keys.secret().as_ref())
             .build_responder()
             .map_err(NoiseError::from);
-        handshake::rt1_responder(socket, session,
+        handshake::rt1_responder(
+            socket,
+            session,
             self.dh_keys.into_identity(),
             IdentityExchange::Mutual,
-            self.legacy)
+            self.legacy,
+        )
     }
 }
 
@@ -204,14 +209,19 @@ where
     type Future = Handshake<T, C>;
 
     fn upgrade_outbound(self, socket: T, _: Self::Info) -> Self::Future {
-        let session = self.params.into_builder()
+        let session = self
+            .params
+            .into_builder()
             .local_private_key(self.dh_keys.secret().as_ref())
             .build_initiator()
             .map_err(NoiseError::from);
-        handshake::rt1_initiator(socket, session,
-                                 self.dh_keys.into_identity(),
-                                 IdentityExchange::Mutual,
-                                 self.legacy)
+        handshake::rt1_initiator(
+            socket,
+            session,
+            self.dh_keys.into_identity(),
+            IdentityExchange::Mutual,
+            self.legacy,
+        )
     }
 }
 
@@ -228,14 +238,19 @@ where
     type Future = Handshake<T, C>;
 
     fn upgrade_inbound(self, socket: T, _: Self::Info) -> Self::Future {
-        let session = self.params.into_builder()
+        let session = self
+            .params
+            .into_builder()
             .local_private_key(self.dh_keys.secret().as_ref())
             .build_responder()
             .map_err(NoiseError::from);
-        handshake::rt15_responder(socket, session,
+        handshake::rt15_responder(
+            socket,
+            session,
             self.dh_keys.into_identity(),
             IdentityExchange::Mutual,
-            self.legacy)
+            self.legacy,
+        )
     }
 }
 
@@ -250,14 +265,19 @@ where
     type Future = Handshake<T, C>;
 
     fn upgrade_outbound(self, socket: T, _: Self::Info) -> Self::Future {
-        let session = self.params.into_builder()
+        let session = self
+            .params
+            .into_builder()
             .local_private_key(self.dh_keys.secret().as_ref())
             .build_initiator()
             .map_err(NoiseError::from);
-        handshake::rt15_initiator(socket, session,
+        handshake::rt15_initiator(
+            socket,
+            session,
             self.dh_keys.into_identity(),
             IdentityExchange::Mutual,
-            self.legacy)
+            self.legacy,
+        )
     }
 }
 
@@ -274,14 +294,19 @@ where
     type Future = Handshake<T, C>;
 
     fn upgrade_inbound(self, socket: T, _: Self::Info) -> Self::Future {
-        let session = self.params.into_builder()
+        let session = self
+            .params
+            .into_builder()
             .local_private_key(self.dh_keys.secret().as_ref())
             .build_responder()
             .map_err(NoiseError::from);
-        handshake::rt1_responder(socket, session,
+        handshake::rt1_responder(
+            socket,
+            session,
             self.dh_keys.into_identity(),
             IdentityExchange::Receive,
-            self.legacy)
+            self.legacy,
+        )
     }
 }
 
@@ -296,15 +321,22 @@ where
     type Future = Handshake<T, C>;
 
     fn upgrade_outbound(self, socket: T, _: Self::Info) -> Self::Future {
-        let session = self.params.into_builder()
+        let session = self
+            .params
+            .into_builder()
             .local_private_key(self.dh_keys.secret().as_ref())
             .remote_public_key(self.remote.0.as_ref())
             .build_initiator()
             .map_err(NoiseError::from);
-        handshake::rt1_initiator(socket, session,
+        handshake::rt1_initiator(
+            socket,
+            session,
             self.dh_keys.into_identity(),
-            IdentityExchange::Send { remote: self.remote.1 },
-            self.legacy)
+            IdentityExchange::Send {
+                remote: self.remote.1,
+            },
+            self.legacy,
+        )
     }
 }
 
@@ -322,12 +354,12 @@ where
 /// transport for use with a [`Network`](libp2p_core::Network).
 #[derive(Clone)]
 pub struct NoiseAuthenticated<P, C: Zeroize, R> {
-    config: NoiseConfig<P, C, R>
+    config: NoiseConfig<P, C, R>,
 }
 
 impl<P, C: Zeroize, R> UpgradeInfo for NoiseAuthenticated<P, C, R>
 where
-    NoiseConfig<P, C, R>: UpgradeInfo
+    NoiseConfig<P, C, R>: UpgradeInfo,
 {
     type Info = <NoiseConfig<P, C, R> as UpgradeInfo>::Info;
     type InfoIter = <NoiseConfig<P, C, R> as UpgradeInfo>::InfoIter;
@@ -339,10 +371,9 @@ where
 
 impl<T, P, C, R> InboundUpgrade<T> for NoiseAuthenticated<P, C, R>
 where
-    NoiseConfig<P, C, R>: UpgradeInfo + InboundUpgrade<T,
-        Output = (RemoteIdentity<C>, NoiseOutput<T>),
-        Error = NoiseError
-    > + 'static,
+    NoiseConfig<P, C, R>: UpgradeInfo
+        + InboundUpgrade<T, Output = (RemoteIdentity<C>, NoiseOutput<T>), Error = NoiseError>
+        + 'static,
     <NoiseConfig<P, C, R> as InboundUpgrade<T>>::Future: Send,
     T: AsyncRead + AsyncWrite + Send + 'static,
     C: Protocol<C> + AsRef<[u8]> + Zeroize + Send + 'static,
@@ -352,20 +383,22 @@ where
     type Future = Pin<Box<dyn Future<Output = Result<Self::Output, Self::Error>> + Send>>;
 
     fn upgrade_inbound(self, socket: T, info: Self::Info) -> Self::Future {
-        Box::pin(self.config.upgrade_inbound(socket, info)
-            .and_then(|(remote, io)| match remote {
-                RemoteIdentity::IdentityKey(pk) => future::ok((pk.into_peer_id(), io)),
-                _ => future::err(NoiseError::AuthenticationFailed)
-            }))
+        Box::pin(
+            self.config
+                .upgrade_inbound(socket, info)
+                .and_then(|(remote, io)| match remote {
+                    RemoteIdentity::IdentityKey(pk) => future::ok((pk.to_peer_id(), io)),
+                    _ => future::err(NoiseError::AuthenticationFailed),
+                }),
+        )
     }
 }
 
 impl<T, P, C, R> OutboundUpgrade<T> for NoiseAuthenticated<P, C, R>
 where
-    NoiseConfig<P, C, R>: UpgradeInfo + OutboundUpgrade<T,
-        Output = (RemoteIdentity<C>, NoiseOutput<T>),
-        Error = NoiseError
-    > + 'static,
+    NoiseConfig<P, C, R>: UpgradeInfo
+        + OutboundUpgrade<T, Output = (RemoteIdentity<C>, NoiseOutput<T>), Error = NoiseError>
+        + 'static,
     <NoiseConfig<P, C, R> as OutboundUpgrade<T>>::Future: Send,
     T: AsyncRead + AsyncWrite + Send + 'static,
     C: Protocol<C> + AsRef<[u8]> + Zeroize + Send + 'static,
@@ -375,16 +408,19 @@ where
     type Future = Pin<Box<dyn Future<Output = Result<Self::Output, Self::Error>> + Send>>;
 
     fn upgrade_outbound(self, socket: T, info: Self::Info) -> Self::Future {
-        Box::pin(self.config.upgrade_outbound(socket, info)
-            .and_then(|(remote, io)| match remote {
-                RemoteIdentity::IdentityKey(pk) => future::ok((pk.into_peer_id(), io)),
-                _ => future::err(NoiseError::AuthenticationFailed)
-            }))
+        Box::pin(
+            self.config
+                .upgrade_outbound(socket, info)
+                .and_then(|(remote, io)| match remote {
+                    RemoteIdentity::IdentityKey(pk) => future::ok((pk.to_peer_id(), io)),
+                    _ => future::err(NoiseError::AuthenticationFailed),
+                }),
+        )
     }
 }
 
 /// Legacy configuration options.
-#[derive(Clone)]
+#[derive(Clone, Default)]
 pub struct LegacyConfig {
     /// Whether to continue sending legacy handshake payloads,
     /// i.e. length-prefixed protobuf payloads inside a length-prefixed
@@ -397,12 +433,3 @@ pub struct LegacyConfig {
     /// libp2p implementations.
     pub recv_legacy_handshake: bool,
 }
-
-impl Default for LegacyConfig {
-    fn default() -> Self {
-        Self {
-            send_legacy_handshake: false,
-            recv_legacy_handshake: false,
-        }
-    }
-}
